@@ -1,20 +1,26 @@
 from aiocontroller import EndpointDefTable, client_factory
 from aiocontroller.endpoints import FromUrl
 
+endpoints = EndpointDefTable()
+route_path = '/api/{arg}'
+
+
+class Controller:
+    @endpoints.get(route_path)
+    def handler(self, arg: int) -> None:
+        pass
+
+
+def static_handler(arg: int) -> None:
+    pass
+
 
 def test_read_param():
-    endpoints = EndpointDefTable()
-    route_path = '/api/{arg}'
-
-    class Controller:
-        @endpoints.get(route_path)
-        def handler(arg: int) -> None:
-            pass
-
-    endpoint = endpoints[Controller.handler]
+    h = Controller.handler
+    endpoint = endpoints[h]
 
     assert endpoint.route_path == route_path
-    assert endpoint.controller_method == Controller.handler
+    assert endpoint.controller_method == h
 
     arg_param = endpoint.signature.params[0]
     assert isinstance(arg_param, FromUrl)
